@@ -1,5 +1,6 @@
 import ast
 import urllib
+from django.core.urlresolvers import reverse
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -48,6 +49,9 @@ class TrackingLog(models.Model):
         verbose_name_plural = _(u'tracking logs')
         ordering = ('-created', )
 
+    def get_absolute_url(self):
+        return reverse('detective:trackinglog_detail', args=(self.pk, ))
+
     @property
     def full_path(self):
         return u'%s?%s' % (self.path, self.query_string)
